@@ -41,11 +41,9 @@ def test_filler(maindb,tmpdir):
 def test_schema():
 	db = Database(db_schema='test_schema',**conninfo)
 	db.init_db()
-	yield db
 	db.connection.close()
 
 def test_searchpath():
-	db = Database(db_schema='test_schema',additional_searchpath=['test__db_fillers'],**conninfo)
+	db = Database(db_schema='test_schema',additional_searchpath=['public'],**conninfo)
 	db.init_db()
-	yield db
 	db.connection.close()
